@@ -9,6 +9,16 @@ class LaboroLogger(logging.Logger):
   Any secret stored in the vault instance will be redacted before logging.
   """
 
+  @staticmethod
+  def log_line():
+    logging.info("-" * 80)
+
+  @staticmethod
+  def log_section(prefix, message):
+    LaboroLogger.log_line()
+    logging.info(f"[{prefix}] {message}")
+    LaboroLogger.log_line()
+
   def __init__(self, name, level=logging.NOTSET):
     self.vault = None
     super(LaboroLogger, self).__init__(name, level)
