@@ -30,7 +30,7 @@ class Workflow:
   """
   def __init__(self, name, context):
     self.name = name
-    self.memory = dict()
+    self.store = dict()
     self.session = str(uuid.uuid4())
     self.context = context.reset(self.name, self.session)
 
@@ -52,8 +52,8 @@ class Workflow:
 
   def _instantiate(self, module, cls, args):
     logging.info(f"[+] Object instantiation: {module}.{cls}")
-    return self.context.modulemgr.get_class_from_module(cls=cls,
-                                                        module=module)(args=args)
+    mod = self.context.modulemgr.get_class_from_module(cls=cls, module=module)
+    return mod(store=self.store, args=args)
 
   def run(self):
     """Run the workflow."""
